==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fBipush.h <==
// class soot.coffi.Instruction_Bipush

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 4a57292b47720930 soot_coffi_Instruction__5fBipush
// @dep_class 5ff9461e894d883d soot_coffi_Instruction__5fbyte

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbyte

#include "soot/coffi/Instruction__5fbyte.h"

#ifndef _JC_soot_coffi_Instruction__5fBipush_H_
#define _JC_soot_coffi_Instruction__5fBipush_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fBipush$sub_refs	_jc_soot_coffi_Instruction__5fBipush$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fBipush$sub_nonrefs	_jc_soot_coffi_Instruction__5fBipush$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fBipush$refs	_jc_soot_coffi_Instruction__5fBipush$refs;
typedef struct _jc_soot_coffi_Instruction__5fBipush$nonrefs	_jc_soot_coffi_Instruction__5fBipush$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fBipush$object	_jc_soot_coffi_Instruction__5fBipush$object;

typedef const struct _jc_soot_coffi_Instruction__5fBipush$vmethods	_jc_soot_coffi_Instruction__5fBipush$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fBipush$vtable	_jc_soot_coffi_Instruction__5fBipush$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fBipush$vtype	_jc_soot_coffi_Instruction__5fBipush$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fBipush$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fBipush$object *);
extern void _jc_soot_coffi_Instruction__5fBipush$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fBipush$object *, jbyte);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fBipush$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fBipush$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbyte$vmethods	soot_coffi_Instruction__5fbyte;
	_jc_soot_coffi_Instruction__5fBipush$vmethods	soot_coffi_Instruction__5fBipush;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fBipush$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fBipush$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fBipush$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fBipush$refs {
    _jc_soot_coffi_Instruction__5fBipush$sub_refs	soot_coffi_Instruction__5fBipush;
    _jc_soot_coffi_Instruction__5fbyte$sub_refs	soot_coffi_Instruction__5fbyte;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fBipush$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fBipush$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbyte$sub_nonrefs	soot_coffi_Instruction__5fbyte;
    _jc_soot_coffi_Instruction__5fBipush$sub_nonrefs	soot_coffi_Instruction__5fBipush;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fBipush$object {
	_jc_soot_coffi_Instruction__5fBipush$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fBipush$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fBipush$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fBipush$vtype _jc_soot_coffi_Instruction__5fBipush$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fBipush, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fBipush$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fBipush_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fBipush.h <==
// class soot.coffi.Instruction_Bipush

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 4a57292b47720930 soot_coffi_Instruction__5fBipush
// @dep_class 5ff9461e894d883d soot_coffi_Instruction__5fbyte

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbyte

#include "soot/coffi/Instruction__5fbyte.h"

#ifndef _JC_soot_coffi_Instruction__5fBipush_H_
#define _JC_soot_coffi_Instruction__5fBipush_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fBipush$sub_refs	_jc_soot_coffi_Instruction__5fBipush$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fBipush$sub_nonrefs	_jc_soot_coffi_Instruction__5fBipush$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fBipush$refs	_jc_soot_coffi_Instruction__5fBipush$refs;
typedef struct _jc_soot_coffi_Instruction__5fBipush$nonrefs	_jc_soot_coffi_Instruction__5fBipush$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fBipush$object	_jc_soot_coffi_Instruction__5fBipush$object;

typedef const struct _jc_soot_coffi_Instruction__5fBipush$vmethods	_jc_soot_coffi_Instruction__5fBipush$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fBipush$vtable	_jc_soot_coffi_Instruction__5fBipush$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fBipush$vtype	_jc_soot_coffi_Instruction__5fBipush$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fBipush$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fBipush$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Instruction__5fBipush$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fBipush$object *, jbyte) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fBipush$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fBipush$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbyte$vmethods	soot_coffi_Instruction__5fbyte;
	_jc_soot_coffi_Instruction__5fBipush$vmethods	soot_coffi_Instruction__5fBipush;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fBipush$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fBipush$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fBipush$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fBipush$refs {
    _jc_soot_coffi_Instruction__5fBipush$sub_refs	soot_coffi_Instruction__5fBipush;
    _jc_soot_coffi_Instruction__5fbyte$sub_refs	soot_coffi_Instruction__5fbyte;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fBipush$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fBipush$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbyte$sub_nonrefs	soot_coffi_Instruction__5fbyte;
    _jc_soot_coffi_Instruction__5fBipush$sub_nonrefs	soot_coffi_Instruction__5fBipush;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fBipush$object {
	_jc_soot_coffi_Instruction__5fBipush$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fBipush$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fBipush$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fBipush$vtype _jc_soot_coffi_Instruction__5fBipush$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fBipush, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fBipush$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fBipush_H_ */
